@@ -235,6 +235,20 @@ class baseWebBrowserController:
         
         pass
     
+    @Logger.loggerDecorator('Scraping with BeautifulSoup')
+    def scrapingWithBeautifulSoup(self) -> BeautifulSoup:
+        
+        """
+        BeautifulSoupを使用してスクレイピング
+
+        Parameters
+        ----------
+        None
+        """
+
+        # スクレイピング結果を返す
+        return BeautifulSoup(self.wDriver.page_source, features='lxml')
+    
     @Logger.loggerDecorator('Create PandasData') 
     def createPandasData(self, dfItemInfo:DataFrame, dictItemInfo:dict, keys:list) -> DataFrame:
 
